@@ -1,5 +1,4 @@
 import asyncio
-import json
 import time
 import uuid
 from pathlib import Path
@@ -9,6 +8,8 @@ from fastapi import Request
 from fastapi.responses import Response
 from fastapi.templating import Jinja2Templates
 
+from nicegui import json
+
 from . import globals, outbox
 from .dependencies import generate_js_imports, generate_vue_content
 from .element import Element
@@ -67,7 +68,7 @@ class Client:
     def build_response(self, request: Request, status_code: int = 200) -> Response:
         prefix = request.headers.get('X-Forwarded-Prefix', '')
         vue_html, vue_styles, vue_scripts = generate_vue_content()
-        elements = json.dumps({id: element.to_dict() for id, element in self.elements.items()})
+        elements = json.dumps({id: element._to_dict() for id, element in self.elements.items()})
         return templates.TemplateResponse('index.html', {
             'request': request,
             'client_id': str(self.id),
