@@ -1,5 +1,5 @@
 from collections import deque
-from typing import Optional
+from typing import Any, Optional
 
 from ..dependencies import register_component
 from ..element import Element
@@ -23,7 +23,8 @@ class Log(Element):
         self.style('opacity: 1 !important; cursor: text !important')
         self.lines: deque[str] = deque(maxlen=max_lines)
 
-    def push(self, line: str) -> None:
+    def push(self, line: Any) -> None:
+        line = str(line)
         self.lines.extend(line.splitlines())
         self._props['lines'] = '\n'.join(self.lines)
         self.run_method('push', line)
