@@ -10,6 +10,9 @@ from fastapi.responses import FileResponse, Response
 from fastapi.staticfiles import StaticFiles
 from fastapi_socketio import SocketManager
 
+from nicegui import json
+from nicegui.json.fastapi import NiceGUIJSONResponse
+
 from . import background_tasks, binding, globals, outbox
 from .app import App
 from .client import Client
@@ -19,8 +22,10 @@ from .error import error_content
 from .helpers import safe_invoke
 from .page import page
 
-globals.app = app = App()
-globals.sio = sio = SocketManager(app=app)._sio
+globals.app = app = App(default_response_class=NiceGUIJSONResponse)
+# NOTE we use custom json module which wraps orjson
+socket_manager = SocketManager(app=app, mount_location='/_nicegui_ws/', json=json)
+globals.sio = sio = app.sio
 
 app.add_middleware(GZipMiddleware)
 app.mount('/_nicegui/static', StaticFiles(directory=Path(__file__).parent / 'static'), name='static')
@@ -129,7 +134,7 @@ def handle_event(sid: str, msg: Dict) -> None:
     with client:
         sender = client.elements.get(msg['id'])
         if sender:
-            sender.handle_event(msg)
+            sender._handle_event(msg)
 
 
 @sio.on('javascript_response')
